summaryrefslogtreecommitdiffstats
path: root/kapptemplate/kapp
diff options
context:
space:
mode:
Diffstat (limited to 'kapptemplate/kapp')
-rw-r--r--kapptemplate/kapp/app.cpp6
-rw-r--r--kapptemplate/kapp/app.h2
2 files changed, 4 insertions, 4 deletions
diff --git a/kapptemplate/kapp/app.h b/kapptemplate/kapp/app.h
index 7c80c0f2..bc96132f 100644
--- a/kapptemplate/kapp/app.h
+++ b/kapptemplate/kapp/app.h
@@ -23,7 +23,7 @@ class KURL;
* @author $AUTHOR <$EMAIL>
* @version $APP_VERSION
*/
-class ${APP_NAME} : public KMainWindow
+class ${APP_NAME} : public TDEMainWindow
{
Q_OBJECT
diff --git a/kapptemplate/kapp/app.cpp b/kapptemplate/kapp/app.cpp
index df8cc8ed..62f1a261 100644
--- a/kapptemplate/kapp/app.cpp
+++ b/kapptemplate/kapp/app.cpp
@@ -34,14 +34,14 @@ cat << EOF > $LOCATION_ROOT/${APP_NAME_LC}/${APP_NAME_LC}.cpp
#include <kstdaction.h>
${APP_NAME}::${APP_NAME}()
- : KMainWindow( 0, "${APP_NAME}" ),
+ : TDEMainWindow( 0, "${APP_NAME}" ),
m_view(new ${APP_NAME}View(this)),
m_printer(0)
{
// accept dnd
setAcceptDrops(true);
// tell the KMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions
@@ -102,7 +102,7 @@ void ${APP_NAME}::setupActions()
// this doesn't do anything useful. it's just here to illustrate
// how to insert a custom menu and menu item
- KAction *custom = new KAction(i18n("Cus&tom Menuitem"), 0,
+ TDEAction *custom = new TDEAction(i18n("Cus&tom Menuitem"), 0,
this, TQT_SLOT(optionsPreferences()),
actionCollection(), "custom_action");
}
@@ -34,14 +34,14 @@ cat << EOF > $LOCATION_ROOT/${APP_NAME_LC}/${APP_NAME_LC}.cpp
// accept dnd
setAcceptDrops(true);
- // tell the KMainWindow that this is indeed the main widget
+ // tell the TDEMainWindow that this is indeed the main widget
setCentralWidget(m_view);
// then, setup our actions